@@ -5,12 +5,15 @@ use Role::Tiny;
 use Carp qw/croak/;
 use Test::More ();
 
-our $VERSION = '1.002002'; # VERSION
+our $VERSION = '1.003002'; # VERSION
 
 sub d {
     my ( $self, $selector ) = @_;
-    return $self if $self->success;
+    return $self->success ? $self : $self->da( $selector );
+}
 
+sub da {
+    my ( $self, $selector ) = @_;
     my $markup = length $selector
         ? $self->tx->res->dom->at($selector)
         : $self->tx->res->dom;
@@ -23,7 +26,7 @@ sub d {
 
     Test::More::diag "\nDEBUG DUMPER:\n$markup\n\n";
 
-    return $self;
+    $self;
 }
 
 q|
@@ -56,6 +59,7 @@ Test::Mojo::Role::Debug - Test::Mojo role to make debugging test failures easier
         ->element_exists('non_existant')
         ->d         # Dump entire DOM on fail
         ->d('#foo') # Dump a specific element on fail
+        ->da        # Always dump
     ;
 
     done_testing;
@@ -83,6 +87,14 @@ dumps the DOM of the current page to the screen. B<Takes> an optional
 selector to be passed to L<Mojo::DOM/"at">, in which case, only
 the markup of that element will be dumped.
 
+=head2 C<da>
+
+    $t->da;
+    $t->da('#foo');
+
+Same as L</d>, except it always dumps, regardless of whether the previous
+test failed or not.
+
 =head1 SEE ALSO
 
 L<Test::Mojo> (L<Test::Mojo/"or"> in particular), L<Mojo::DOM>
